==> glibc-2.20.tar.xz: glibc-2.20/bits/sigstack.h <==
/* sigstack, sigaltstack definitions.
   Copyright (C) 1998-2014 Free Software Foundation, Inc.
   This file is part of the GNU C Library.

   The GNU C Library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
   License as published by the Free Software Foundation; either
   version 2.1 of the License, or (at your option) any later version.

   The GNU C Library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Lesser General Public License for more details.

   You should have received a copy of the GNU Lesser General Public
   License along with the GNU C Library; if not, see
   <http://www.gnu.org/licenses/>.  */

#ifndef _SIGNAL_H
# error "Never include this file directly.  Use <signal.h> instead"
#endif


/* Structure describing a signal stack (obsolete).  */
struct sigstack
  {
    __ptr_t ss_sp;		/* Signal stack pointer.  */
    int ss_onstack;		/* Nonzero if executing on this stack.  */
  };


/* Alternate, preferred interface.  */
typedef struct sigaltstack
  {
    __ptr_t ss_sp;
    size_t ss_size;
    int ss_flags;
  } stack_t;


/* Possible values for `ss_flags.'.  */
enum
{
  SS_ONSTACK = 0x0001,
#define SS_ONSTACK	SS_ONSTACK
  SS_DISABLE = 0x0004
#define SS_DISABLE	SS_DISABLE
};

/* Minumum stack size for a signal handler.  */
#define MINSIGSTKSZ	8192

/* System default stack size.  */
#define SIGSTKSZ	(MINSIGSTKSZ + 32768)

==> glibc-2.25.tar.xz: glibc-2.25/bits/sigstack.h <==
/* sigstack, sigaltstack definitions.
   Copyright (C) 1998-2017 Free Software Foundation, Inc.
   This file is part of the GNU C Library.

   The GNU C Library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
   License as published by the Free Software Foundation; either
   version 2.1 of the License, or (at your option) any later version.

   The GNU C Library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Lesser General Public License for more details.

   You should have received a copy of the GNU Lesser General Public
   License along with the GNU C Library; if not, see
   <http://www.gnu.org/licenses/>.  */

#ifndef _BITS_SIGSTACK_H
#define _BITS_SIGSTACK_H 1

#if !defined _SIGNAL_H && !defined _SYS_UCONTEXT_H
# error "Never include this file directly.  Use <signal.h> instead"
#endif


/* Structure describing a signal stack (obsolete).  */
struct sigstack
  {
    __ptr_t ss_sp;		/* Signal stack pointer.  */
    int ss_onstack;		/* Nonzero if executing on this stack.  */
  };


/* Alternate, preferred interface.  */
typedef struct sigaltstack
  {
    __ptr_t ss_sp;
    size_t ss_size;
    int ss_flags;
  } stack_t;


/* Possible values for `ss_flags.'.  */
enum
{
  SS_ONSTACK = 0x0001,
#define SS_ONSTACK	SS_ONSTACK
  SS_DISABLE = 0x0004
#define SS_DISABLE	SS_DISABLE
};

/* Minumum stack size for a signal handler.  */
#define MINSIGSTKSZ	8192

/* System default stack size.  */
#define SIGSTKSZ	(MINSIGSTKSZ + 32768)

#endif /* bits/sigstack.h */
